#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-overloaded-record-dot-plugin
version:              2.3.0.0
visibility:           public
id:
    hls-overloaded-record-dot-plugin-2.3.0.0-4CL3j5n69oH7af6IUwUdDM

key:
    hls-overloaded-record-dot-plugin-2.3.0.0-4CL3j5n69oH7af6IUwUdDM

license:              BSD-3-Clause
maintainer:           joyfulmantis@gmail.com
author:               Nathan Maxson
synopsis:             Overloaded record dot plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  e65e422ab7d4def369294b619072a412
exposed:              True
exposed-modules:      Ide.Plugin.OverloadedRecordDot
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-overloaded-record-dot-plugin-2.3.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-overloaded-record-dot-plugin-2.3.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/hls-overloaded-record-dot-plugin-2.3.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-overloaded-record-dot-plugin
hs-libraries:
    HShls-overloaded-record-dot-plugin-2.3.0.0-4CL3j5n69oH7af6IUwUdDM

depends:
    aeson-2.2.2.0-C59vZnSjH3DEmVbOnYEZqj base-4.18.2.1 containers-0.6.7
    deepseq-1.4.8.1 ghc-boot-th-9.6.6
    ghcide-2.3.0.0-5ssdDHVSHun4CTi9Kh39ZX
    hls-graph-2.3.0.0-BKCw9wgtA1S1PhMBjmLsTw
    hls-plugin-api-2.3.0.0-4xBXilkZH7I1XWpO94lJCk
    lens-5.3.5-BDZkiRzgsgQ2kD9evujAJa
    lsp-2.2.0.0-6w4y1QddwBxGRyqRyrutmt syb-0.7.3-11K0viXu9hkJBGIPMEQMvn
    text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.21-LjCRrPGX8vKp2UxAfh6M2

haddock-interfaces:
    /usr/share/doc/haskell-hls-overloaded-record-dot-plugin/html/hls-overloaded-record-dot-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-overloaded-record-dot-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

